@@ -251,7 +251,7 @@ sub _preamble {
 
 =head2 version
 
-Equivalent to C<$self-<gt>server_versions-<gt>versionName>.
+Equivalent to C<$self-E<gt>server_versions-E<gt>versionName>.
 
 =cut
 
@@ -291,5 +291,8 @@ sub _check_for_errors {
 	    Carp::croak $msg
 	}
     }
+
+    return;
 }
+
 1;
